@@ -30,7 +30,6 @@ import pytest
 import libqtile.config
 from libqtile import layout
 from libqtile.confreader import Config
-from test.conftest import no_xinerama
 from test.layouts.layout_utils import assert_focus_path, assert_focused
 
 
@@ -51,8 +50,7 @@ class MaxConfig(Config):
     screens = []
 
 
-def max_config(x):
-    return no_xinerama(pytest.mark.parametrize("manager", [MaxConfig], indirect=True)(x))
+max_config = pytest.mark.parametrize("manager", [MaxConfig], indirect=True)
 
 
 @max_config
