@@ -30,7 +30,6 @@ import pytest
 import libqtile.config
 from libqtile import layout
 from libqtile.confreader import Config
-from test.conftest import no_xinerama
 from test.layouts.layout_utils import (
     assert_dimensions,
     assert_focus_path,
@@ -52,8 +51,7 @@ class ZoomyConfig(Config):
     screens = []
 
 
-def zoomy_config(x):
-    return no_xinerama(pytest.mark.parametrize("manager", [ZoomyConfig], indirect=True)(x))
+zoomy_config = pytest.mark.parametrize("manager", [ZoomyConfig], indirect=True)
 
 
 @zoomy_config
